import base64

import qrcode
from django import template
from django.urls import reverse
from django.utils.encoding import force_bytes

from qrcode2.utils import img_to_base64_data

register = template.Library()


@register.filter
def qrcode_src(text):
    try:
        return reverse('qrcode', args=(base64.b64encode(force_bytes(text)),))
    except Exception as e:
        img = qrcode.make(str(text))
        return img_to_base64_data(img)



import base64

import qrcode
from django.http import HttpResponse


def qrcode_img_view(request, b64code):
    content = base64.urlsafe_b64decode(b64code.encode())
    resp = HttpResponse(content_type="image/png")
    img = qrcode.make(content)
    img.save(resp)
    return resp



import base64
import io


def img_to_base64_data(img):
    in_mem_file = io.BytesIO()
    img.save(in_mem_file, format='PNG')
    in_mem_file.seek(0)
    img_bytes = in_mem_file.read()
    return 'data:image/png;base64,' + base64.b64encode(img_bytes).decode('utf-8')
